/*
  Liquid War 6 is a unique multiplayer wargame.
  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015  Christian Mauduit <ufoot@ufoot.org>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.


  Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
  Contact author        : ufoot@ufoot.org
*/

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif // HAVE_CONFIG_H

#include "../gfx.h"
#include "mod-caca-internal.h"

char *
_mod_caca_repr (lw6sys_context_t * sys_context, _mod_caca_context_t * caca_context, u_int32_t id)
{
  char *ret = NULL;
  const char *caca_version = NULL;

  caca_version = lw6sys_str_empty_if_null (sys_context, caca_get_version ());
  ret =
    lw6sys_new_sprintf (sys_context, _x_
			("%u caca libcaca version %s resolution %dx%d"), id, caca_version, caca_context->video_mode.width, caca_context->video_mode.height);

  return ret;
}
